==> airframe-http-netty_3-22.10.4-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"airframe-http-netty","t":"airframe-http-netty","d":"","k":"static"},
{"l":"wvlet/airframe/http/netty.html#","e":false,"i":"","n":"wvlet.airframe.http.netty","t":"wvlet.airframe.http.netty","d":"","k":"package"},
{"l":"wvlet/airframe/http/netty/NetthRequestHandler.html#","e":false,"i":"","n":"NetthRequestHandler","t":"NetthRequestHandler(config: NettyServerConfig, dispatcher: Filter) extends SimpleChannelInboundHandler[FullHttpRequest] with LogSupport","d":"wvlet.airframe.http.netty","k":"class"},
{"l":"wvlet/airframe/http/netty/Netty$.html#","e":false,"i":"","n":"Netty","t":"Netty","d":"wvlet.airframe.http.netty","k":"object"},
{"l":"wvlet/airframe/http/netty/Netty$.html#server-0","e":false,"i":"","n":"server","t":"server: NettyServerConfig","d":"wvlet.airframe.http.netty.Netty","k":"def"},
{"l":"wvlet/airframe/http/netty/NettyBackend$.html#","e":false,"i":"","n":"NettyBackend","t":"NettyBackend extends HttpBackend[Request, Response, Rx]","d":"wvlet.airframe.http.netty","k":"object"},
{"l":"wvlet/airframe/http/netty/NettyResponseHandler.html#","e":false,"i":"","n":"NettyResponseHandler","t":"NettyResponseHandler extends ResponseHandler[Request, Response] with LogSupport","d":"wvlet.airframe.http.netty","k":"class"},
{"l":"wvlet/airframe/http/netty/NettyServer.html#","e":false,"i":"","n":"NettyServer","t":"NettyServer(config: NettyServerConfig, session: Session) extends AutoCloseable with LogSupport","d":"wvlet.airframe.http.netty","k":"class"},
{"l":"wvlet/airframe/http/netty/NettyServer.html#localAddress-0","e":false,"i":"","n":"localAddress","t":"localAddress: String","d":"wvlet.airframe.http.netty.NettyServer","k":"val"},
{"l":"wvlet/airframe/http/netty/NettyServer.html#start-0","e":false,"i":"","n":"start","t":"start: Unit","d":"wvlet.airframe.http.netty.NettyServer","k":"def"},
{"l":"wvlet/airframe/http/netty/NettyServerConfig.html#","e":false,"i":"","n":"NettyServerConfig","t":"NettyServerConfig(serverPort: Option[Int], controllerProvider: ControllerProvider, router: Router, useEpoll: Boolean)","d":"wvlet.airframe.http.netty","k":"class"},
{"l":"wvlet/airframe/http/netty/NettyServerConfig.html#design-0","e":false,"i":"","n":"design","t":"design: Design","d":"wvlet.airframe.http.netty.NettyServerConfig","k":"def"},
{"l":"wvlet/airframe/http/netty/NettyServerConfig.html#designWithSyncClient-0","e":false,"i":"","n":"designWithSyncClient","t":"designWithSyncClient: Design","d":"wvlet.airframe.http.netty.NettyServerConfig","k":"def"},
{"l":"wvlet/airframe/http/netty/NettyServerConfig.html#newServer-7ef","e":false,"i":"","n":"newServer","t":"newServer(session: Session): NettyServer","d":"wvlet.airframe.http.netty.NettyServerConfig","k":"def"},
{"l":"wvlet/airframe/http/netty/NettyServerConfig.html#port-0","e":false,"i":"","n":"port","t":"port: Int","d":"wvlet.airframe.http.netty.NettyServerConfig","k":"val"},
{"l":"wvlet/airframe/http/netty/NettyServerConfig.html#withRouter-d8","e":false,"i":"","n":"withRouter","t":"withRouter(router: Router): NettyServerConfig","d":"wvlet.airframe.http.netty.NettyServerConfig","k":"def"}];

==> airframe-http-netty_3-23.1.2-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"airframe-http-netty","t":"airframe-http-netty","d":"","k":"static"},
{"l":"wvlet/airframe/http/netty.html#","e":false,"i":"","n":"wvlet.airframe.http.netty","t":"wvlet.airframe.http.netty","d":"","k":"package"},
{"l":"wvlet/airframe/http/netty/NetthRequestHandler.html#","e":false,"i":"","n":"NetthRequestHandler","t":"NetthRequestHandler(config: NettyServerConfig, dispatcher: Filter) extends SimpleChannelInboundHandler[FullHttpRequest] with LogSupport","d":"wvlet.airframe.http.netty","k":"class"},
{"l":"wvlet/airframe/http/netty/Netty$.html#","e":false,"i":"","n":"Netty","t":"Netty","d":"wvlet.airframe.http.netty","k":"object"},
{"l":"wvlet/airframe/http/netty/Netty$.html#server-0","e":false,"i":"","n":"server","t":"server: NettyServerConfig","d":"wvlet.airframe.http.netty.Netty","k":"def"},
{"l":"wvlet/airframe/http/netty/NettyBackend$.html#","e":false,"i":"","n":"NettyBackend","t":"NettyBackend extends HttpBackend[Request, Response, Rx]","d":"wvlet.airframe.http.netty","k":"object"},
{"l":"wvlet/airframe/http/netty/NettyResponseHandler.html#","e":false,"i":"","n":"NettyResponseHandler","t":"NettyResponseHandler extends ResponseHandler[Request, Response] with LogSupport","d":"wvlet.airframe.http.netty","k":"class"},
{"l":"wvlet/airframe/http/netty/NettyServer.html#","e":false,"i":"","n":"NettyServer","t":"NettyServer(config: NettyServerConfig, session: Session) extends AutoCloseable with LogSupport","d":"wvlet.airframe.http.netty","k":"class"},
{"l":"wvlet/airframe/http/netty/NettyServer.html#localAddress-0","e":false,"i":"","n":"localAddress","t":"localAddress: String","d":"wvlet.airframe.http.netty.NettyServer","k":"val"},
{"l":"wvlet/airframe/http/netty/NettyServer.html#start-0","e":false,"i":"","n":"start","t":"start: Unit","d":"wvlet.airframe.http.netty.NettyServer","k":"def"},
{"l":"wvlet/airframe/http/netty/NettyServerConfig.html#","e":false,"i":"","n":"NettyServerConfig","t":"NettyServerConfig(serverPort: Option[Int], controllerProvider: ControllerProvider, router: Router, useEpoll: Boolean)","d":"wvlet.airframe.http.netty","k":"class"},
{"l":"wvlet/airframe/http/netty/NettyServerConfig.html#design-0","e":false,"i":"","n":"design","t":"design: Design","d":"wvlet.airframe.http.netty.NettyServerConfig","k":"def"},
{"l":"wvlet/airframe/http/netty/NettyServerConfig.html#designWithSyncClient-0","e":false,"i":"","n":"designWithSyncClient","t":"designWithSyncClient: Design","d":"wvlet.airframe.http.netty.NettyServerConfig","k":"def"},
{"l":"wvlet/airframe/http/netty/NettyServerConfig.html#newServer-7ef","e":false,"i":"","n":"newServer","t":"newServer(session: Session): NettyServer","d":"wvlet.airframe.http.netty.NettyServerConfig","k":"def"},
{"l":"wvlet/airframe/http/netty/NettyServerConfig.html#port-0","e":false,"i":"","n":"port","t":"port: Int","d":"wvlet.airframe.http.netty.NettyServerConfig","k":"val"},
{"l":"wvlet/airframe/http/netty/NettyServerConfig.html#withRouter-d8","e":false,"i":"","n":"withRouter","t":"withRouter(router: Router): NettyServerConfig","d":"wvlet.airframe.http.netty.NettyServerConfig","k":"def"},
{"l":"wvlet/airframe/http/netty/RxNettyBackend.html#","e":false,"i":"","n":"RxNettyBackend","t":"RxNettyBackend extends RxHttpBackend","d":"wvlet.airframe.http.netty","k":"class"}];
